@@ -12,10 +12,17 @@ from .metadata import Metadata
 from .message import Message
 from .message_summary import MessageSummary
 from .message_list_result import MessageListResult
+from .message_create_options import MessageCreateOptions
+from .message_forward_options import MessageForwardOptions
+from .message_reply_options import MessageReplyOptions
 from .search_criteria import SearchCriteria
 from .server import Server
 from .server_list_result import ServerListResult
 from .server_create_options import ServerCreateOptions
+from .usage_account_limits import UsageAccountLimits
+from .usage_account_limit import UsageAccountLimit
+from .usage_transaction_list_result import UsageTransactionListResult
+from .usage_transaction import UsageTransaction
 
 __all__ = [
     'SpamAssassinRule',
@@ -32,8 +39,15 @@ __all__ = [
     'Message',
     'MessageSummary',
     'MessageListResult',
+    'MessageCreateOptions',
+    'MessageForwardOptions',
+    'MessageReplyOptions',
     'SearchCriteria',
     'Server',
     'ServerListResult',
     'ServerCreateOptions',
+    'UsageAccountLimits',
+    'UsageAccountLimit',
+    'UsageTransactionListResult',
+    'UsageTransaction'
 ]
