@@ -7,3 +7,8 @@ class ServerCreateOptions(object):
 
     def __init__(self, name=None):
         self.name = name
+
+    def to_json(self):
+        return {
+            'name': self.name
+        }
